/*! \file BoolElementResult.h 
 *  \brief: header file for bool result object
 *  A boll result object is just derived from a BoolInput object, with additional time and step information.
 */


#ifndef _BOOLELEMENTRESULT_H_
#define _BOOLELEMENTRESULT_H_

/*Headers:*/
/*{{{1*/
#include "../Inputs/Input.h"
#include "../../include/include.h"
class Parameters;
/*}}}*/

class BoolElementResult: public ElementResult{

	private: 
		int    enum_type;
		bool   value;
		int    step;
		double time;

	public:

		/*BoolElementResult constructors, destructors: {{{1*/
		BoolElementResult();
		BoolElementResult(int enum_type,bool value,int step,double time);
		~BoolElementResult();
		/*}}}*/
		/*Object virtual functions definitions:{{{1 */
		void  Echo();
		void  DeepEcho();
		int   Id(); 
		int   MyRank();
		void  Marshall(char** pmarshalled_dataset);
		int   MarshallSize();
		void  Demarshall(char** pmarshalled_dataset);
		int   Enum();
		Object* copy();
		/*}}}*/
		/*ElementResult virtual functions definitions: {{{1*/
		ElementResult* SpawnTriaElementResult(int* indices);
		void    ProcessUnits(Parameters* parameters);
		int     NumberOfNodalValues(void);
		void    PatchFill(int row, Patch* patch);
		/*}}}*/
		/*BoolElementResult management: {{{1*/
		int   EnumType();
		/*}}}*/
};
#endif  /* _BOOLELEMENTRESULT_H */
